<?php

namespace Api;

use Auth\Ldap;

/**
 * User API controller
 *
 * @package  api
 * @author   Frederic Guillot
 */
class User extends Base
{
    public function getUser($user_id)
    {
        return $this->user->getById($user_id);
    }

    public function getAllUsers()
    {
        return $this->user->getAll();
    }

    public function removeUser($user_id)
    {
        return $this->user->remove($user_id);
    }

    public function createUser($username, $password, $name = '', $email = '', $is_admin = 0, $default_project_id = 0)
    {
        $values = array(
            'username' => $username,
            'password' => $password,
            'confirmation' => $password,
            'name' => $name,
            'email' => $email,
            'is_admin' => $is_admin,
            'default_project_id' => $default_project_id,
        );

        list($valid,) = $this->user->validateCreation($values);

        return $valid ? $this->user->create($values) : false;
    }

    public function createLdapUser($username = '', $email = '', $is_admin = 0, $default_project_id = 0)
    {
        $ldap = new Ldap($this->container);
        $user = $ldap->lookup($username, $email);

        if (! $user) {
            return false;
        }

        $values = array(
            'username' => $user['username'],
            'name' => $user['name'],
            'email' => $user['email'],
            'is_ldap_user' => 1,
            'is_admin' => $is_admin,
            'default_project_id' => $default_project_id,
        );

        return $this->user->create($values);
    }

    public function updateUser($id, $username = null, $name = null, $email = null, $is_admin = null, $default_project_id = null)
    {
        $values = array(
            'id' => $id,
            'username' => $username,
            'name' => $name,
            'email' => $email,
            'is_admin' => $is_admin,
            'default_project_id' => $default_project_id,
        );

        foreach ($values as $key => $value) {
            if (is_null($value)) {
                unset($values[$key]);
            }
        }

        list($valid,) = $this->user->validateApiModification($values);
        return $valid && $this->user->update($values);
    }
}
